module.exports={A:{A:{"1":"A B","2":"J E F G lB"},B:{"1":"C K L D M N O","516":"P Q R U V W X Y Z a b c S d e H"},C:{"132":"DB EB FB GB HB IB JB eB KB fB LB MB T","164":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB oB pB","516":"NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c","1028":"S d e H gB"},D:{"420":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB","516":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"A B C K L D iB bB cB xB yB zB","132":"G wB","164":"E F vB","420":"I f J sB hB tB uB"},F:{"1":"C bB jB 4B cB","2":"G B 0B 1B 2B 3B","420":"D M N O g h i j k l m n o p q r s t u v w x","516":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"1":"D CC DC EC FC GC HC IC JC KC LC MC NC","132":"AC BC","164":"F 8B 9B","420":"hB 5B kB 6B 7B"},H:{"1":"OC"},I:{"420":"dB I PC QC RC SC kB TC UC","516":"H"},J:{"420":"E A"},K:{"1":"C bB jB cB","2":"A B","516":"T"},L:{"516":"H"},M:{"516":"S"},N:{"1":"A B"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","420":"I"},Q:{"132":"gC"},R:{"132":"hC"},S:{"164":"iC"}},B:4,C:"CSS3 Multiple column layout"};
