module.exports={A:{A:{"2":"J E F G A lB","2052":"B"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","132":"mB dB I f J E F G A B C oB pB","260":"K L D M N O g h i j k l m n o p q r s t u v w"},D:{"1":"AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","260":"I f J E F G A B C K L D M N O g h","772":"0 1 i j k l m n o p q r s t u v w x y z","1028":"2 3 4 5 6 7 8 9"},E:{"1":"B C K L D bB cB xB yB zB","260":"I f A sB hB iB","772":"J E F G tB uB vB wB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G 0B","132":"B 1B 2B 3B bB jB","644":"C 4B cB","772":"D M N O g h i j k l m n o","1028":"p q r s t u v w"},G:{"1":"D EC FC GC HC IC JC KC LC MC NC","260":"hB 5B kB CC DC","772":"F 6B 7B 8B 9B AC BC"},H:{"644":"OC"},I:{"1":"H","16":"PC QC","260":"RC","772":"dB I SC kB TC UC"},J:{"772":"E A"},K:{"1":"T","132":"A B bB jB","644":"C cB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","2":"A"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","1028":"I"},Q:{"1":"gC"},R:{"1028":"hC"},S:{"1":"iC"}},B:6,C:"const"};
