module.exports={A:{A:{"2":"lB","8":"J E F G A","129":"B"},B:{"1":"P Q R U V W X Y Z a b c S d e H","129":"C K L D M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB oB pB","129":"I f J E F G A B C K L D M N O g h i j k"},D:{"1":"0 1 2 3 4 5 6 7 8 9 u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E","129":"F G A B C K L D M N O g h i j k l m n o p q r s t"},E:{"1":"F G A B C K L D wB iB bB cB xB yB zB","2":"I f sB hB","129":"J E tB uB vB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B 0B 1B 2B 3B bB jB 4B","129":"C D M N O cB"},G:{"1":"F D 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","2":"hB 5B kB 6B 7B 8B"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"1":"A","2":"E"},K:{"1":"C T cB","2":"A B bB jB"},L:{"1":"H"},M:{"1":"S"},N:{"8":"A","129":"B"},O:{"129":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"129":"iC"}},B:6,C:"WebGL - 3D Canvas graphics"};
