module.exports={A:{A:{"1":"G A B","2":"lB","8":"J E F"},B:{"1":"C K L D M N O","129":"P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB oB pB","8":"mB dB","129":"GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB","4":"I","129":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"f J E F G B C K L D tB uB vB wB iB bB cB xB yB zB","8":"I sB hB","129":"A"},F:{"1":"B C M N O g h i j k l m n o p q r s t u v w x y z 3B bB jB 4B cB","2":"G D 0B","8":"1B 2B","129":"0 1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"1":"F hB 5B kB 6B 7B 8B 9B AC BC","129":"D CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"dB I PC QC RC SC kB TC UC","129":"H"},J:{"1":"E A"},K:{"1":"B C bB jB cB","8":"A","129":"T"},L:{"129":"H"},M:{"129":"S"},N:{"1":"A B"},O:{"1":"VC"},P:{"1":"I","129":"WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"129":"gC"},R:{"129":"hC"},S:{"1":"iC"}},B:2,C:"Geolocation"};
