module.exports={A:{A:{"1":"B","2":"J E F G A lB"},B:{"2":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB","2":"mB dB I f J E F G A B C CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB","2":"CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"F G A B C wB iB bB","2":"I f J E sB hB tB uB vB","129":"K L D cB xB yB zB"},F:{"1":"0 3 5 D M N O g h i j k l m n o p q r s t u v w x y z cB","2":"1 2 4 6 7 8 9 G B C AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B bB jB 4B"},G:{"1":"F 9B AC BC CC DC EC FC GC","2":"hB 5B kB 6B 7B 8B","257":"D HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"dB I SC kB TC UC","2":"H PC QC RC"},J:{"2":"E A"},K:{"1":"cB","2":"A B C T bB jB"},L:{"2":"H"},M:{"2":"S"},N:{"1":"B","2":"A"},O:{"2":"VC"},P:{"1":"I","2":"WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"2":"gC"},R:{"16":"hC"},S:{"1":"iC"}},B:7,C:"SPDY protocol"};
