module.exports={A:{A:{"2":"J E F G lB","130":"A B"},B:{"130":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB oB pB","130":"I f J E F G A B C K L D M N O g h i j k","322":"l m n o p q r s t u"},D:{"2":"I f J E F G A B C K L D","130":"0 1 2 3 4 5 6 7 8 9 M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"A B C K L D wB iB bB cB xB yB zB","2":"E F G sB hB uB vB","130":"I f J tB"},F:{"2":"G B C 0B 1B 2B 3B bB jB 4B cB","130":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"1":"D BC CC DC EC FC GC HC IC JC KC LC MC NC","2":"F hB 8B 9B AC","130":"5B kB 6B 7B"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB","130":"H TC UC"},J:{"2":"E","130":"A"},K:{"2":"A B C bB jB cB","130":"T"},L:{"130":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"130":"VC"},P:{"130":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"130":"gC"},R:{"130":"hC"},S:{"1":"iC"}},B:5,C:"CSS font-variant-alternates"};
