module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"N O","2":"C K L D M","257":"P Q R U V W X Y Z a b c S d e H"},C:{"2":"0 1 2 3 4 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z oB pB","257":"5 7 8 9 AB BB CB EB FB GB HB IB JB eB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","1281":"6 DB KB"},D:{"2":"0 1 2 3 4 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z","257":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","388":"5 6 7 8 9 AB"},E:{"2":"I f J E F G sB hB tB uB vB","514":"A B C K L D wB iB bB cB xB yB","2114":"zB"},F:{"2":"G B C D M N O g h i j k l m n o p q r s t u v w x 0B 1B 2B 3B bB jB 4B cB","16":"0 1 2 y z","257":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I H PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"2":"hC"},S:{"257":"iC"}},B:5,C:"Push API"};
