module.exports={A:{A:{"1":"A B","2":"J E F G lB"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I oB pB","33":"f J E F G A B C K L D"},D:{"1":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","33":"0 1 2 3 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z"},E:{"1":"G A B C K L D wB iB bB cB xB yB zB","2":"sB hB","33":"J E F tB uB vB","292":"I f"},F:{"1":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R cB","2":"G B 0B 1B 2B 3B bB jB 4B","33":"C D M N O g h i j k l m n o p q"},G:{"1":"D AC BC CC DC EC FC GC HC IC JC KC LC MC NC","33":"F 7B 8B 9B","164":"hB 5B kB 6B"},H:{"2":"OC"},I:{"1":"H","33":"I SC kB TC UC","164":"dB PC QC RC"},J:{"33":"E A"},K:{"1":"T cB","2":"A B C bB jB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"33":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:5,C:"CSS Animation"};
