module.exports={A:{A:{"2":"J E F lB","2561":"A B","2692":"G"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2561":"C K L D M N O"},C:{"1":"AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","16":"mB","1537":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z pB","1796":"dB oB"},D:{"1":"OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","16":"I f J E F G A B C K L","1025":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB","1537":"D M N O g h i j k l m n o p q r s t u v"},E:{"1":"L D xB yB zB","16":"I f J sB hB","1025":"E F G A B C uB vB wB iB bB","1537":"tB","4097":"K cB"},F:{"1":"DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R cB","16":"G B C 0B 1B 2B 3B bB jB","260":"4B","1025":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w x y z AB BB CB","1537":"D M N O g h i"},G:{"16":"hB 5B kB","1025":"F D 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","1537":"6B 7B 8B"},H:{"2":"OC"},I:{"16":"PC QC","1025":"H UC","1537":"dB I RC SC kB TC"},J:{"1025":"A","1537":"E"},K:{"1":"A B C bB jB cB","1025":"T"},L:{"1":"H"},M:{"1537":"S"},N:{"2561":"A B"},O:{"1537":"VC"},P:{"1025":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1025":"gC"},R:{"1025":"hC"},S:{"1537":"iC"}},B:1,C:"input event"};
