module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2":"C","260":"K L D M N O"},C:{"1":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p oB pB","516":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB"},D:{"1":"EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I","16":"f J E F G A B C K L","260":"DB","772":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB"},E:{"1":"B C K L D iB bB cB xB yB zB","2":"I sB hB","16":"f","772":"J E F G A tB uB vB wB"},F:{"1":"1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","16":"G 0B","260":"0 B C 1B 2B 3B bB jB 4B cB","772":"D M N O g h i j k l m n o p q r s t u v w x y z"},G:{"1":"D DC EC FC GC HC IC JC KC LC MC NC","2":"hB 5B kB","772":"F 6B 7B 8B 9B AC BC CC"},H:{"132":"OC"},I:{"1":"H","2":"dB PC QC RC","260":"I SC kB TC UC"},J:{"2":"E","260":"A"},K:{"1":"T","260":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","260":"I"},Q:{"1":"gC"},R:{"1":"hC"},S:{"516":"iC"}},B:5,C:":in-range and :out-of-range CSS pseudo-classes"};
