module.exports={A:{A:{"1":"A B","2":"J E F G lB"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2":"C K L D M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB oB pB","132":"I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x"},D:{"1":"0 1 2 3 4 5 6 7 8 9 n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I","16":"f J E F i j k l m","132":"G A B C K L D M N O g h"},E:{"1":"C K L D bB cB xB yB zB","2":"I f sB hB tB","132":"J E F G A B uB vB wB iB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C 0B 1B 2B 3B bB jB 4B cB"},G:{"2":"7B 8B","132":"F D 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","514":"hB 5B kB 6B"},H:{"2":"OC"},I:{"2":"PC QC RC","260":"dB I SC kB","514":"H TC UC"},J:{"132":"A","260":"E"},K:{"2":"A B C bB jB cB","514":"T"},L:{"260":"H"},M:{"2":"S"},N:{"514":"A","1028":"B"},O:{"2":"VC"},P:{"260":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"260":"gC"},R:{"260":"hC"},S:{"1":"iC"}},B:1,C:"accept attribute for file input"};
