module.exports={A:{A:{"2":"J E F G lB","129":"A B"},B:{"1":"P Q R U V W X Y Z a b c S d e H","129":"C K","1025":"L D M N O"},C:{"2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p oB pB","513":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f"},E:{"1":"f J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB","2":"I sB hB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B bB jB 4B cB"},G:{"388":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB PC QC RC","388":"I H SC kB TC UC"},J:{"2":"E","388":"A"},K:{"1":"A B C bB jB cB","388":"T"},L:{"388":"H"},M:{"641":"S"},N:{"388":"A B"},O:{"388":"VC"},P:{"388":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"388":"gC"},R:{"388":"hC"},S:{"513":"iC"}},B:1,C:"Number input type"};
