module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"P","2":"C K L D M N O Q R U V W X Y Z a b c S d e H"},C:{"2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB oB pB","66":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P","2":"I f J E F G A B C K L D M N O g h i j k l Q R U V W X Y Z a b c S d e H gB qB rB","33":"m n o p q r s t u v"},E:{"2":"I f J E F G A B C K L D sB hB tB uB vB wB iB bB cB xB yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB","2":"G B C PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B bB jB 4B cB","33":"D M N O g h i"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I H PC QC RC SC kB","33":"TC UC"},J:{"2":"E A"},K:{"2":"A B C T bB jB cB"},L:{"2":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC","2":"dC eC fC","33":"I"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:7,C:"Shadow DOM (deprecated V0 spec)"};
