module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2":"C K L D M N O"},C:{"1":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","16":"mB","33":"0 1 2 3 4 5 6 7 8 9 dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB oB pB"},D:{"1":"NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","16":"I f J E F G A B C K L","33":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T"},E:{"1":"G A B C K L D wB iB bB cB xB yB zB","16":"I f J sB hB tB","33":"E F uB vB"},F:{"1":"DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C 0B 1B 2B 3B bB jB 4B cB","33":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB"},G:{"1":"D AC BC CC DC EC FC GC HC IC JC KC LC MC NC","16":"hB 5B kB 6B","33":"F 7B 8B 9B"},H:{"2":"OC"},I:{"1":"H","16":"dB I PC QC RC SC kB","33":"TC UC"},J:{"16":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"33":"VC"},P:{"1":"aC iB bC cC dC eC fC","16":"I","33":"WC XC YC ZC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"33":"iC"}},B:5,C:"CSS :any-link selector"};
