module.exports={A:{A:{"2":"J E F G A lB","132":"B"},B:{"1":"C K L D M N O","4":"P Q R U V W X Y Z a b c S d e H"},C:{"2":"mB dB oB","4":"0 1 2 3 4 5 6 7 8 9 J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","8":"I f pB"},D:{"2":"I f J","4":"0 1 2 3 4 5 6 7 8 9 E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"2":"I f J E F G A B C K L D sB hB tB uB vB wB iB bB cB xB yB zB"},F:{"2":"G B C 0B 1B 2B 3B bB jB 4B cB","4":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"2":"hB 5B","4":"F D kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"PC QC RC","4":"dB I H SC kB TC UC"},J:{"2":"E","4":"A"},K:{"1":"C cB","2":"A B bB jB","4":"T"},L:{"4":"H"},M:{"4":"S"},N:{"1":"B","2":"A"},O:{"4":"VC"},P:{"4":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"4":"gC"},R:{"4":"hC"},S:{"4":"iC"}},B:4,C:"DeviceOrientation & DeviceMotion events"};
