module.exports={A:{A:{"388":"A B","900":"J E F G lB"},B:{"388":"C K L D M N O","900":"P Q R U V W X Y Z a b c S d e H"},C:{"772":"NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","900":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T oB pB"},D:{"900":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"772":"A","900":"I f J E F G B C K L D sB hB tB uB vB wB iB bB cB xB yB zB"},F:{"16":"G 0B","129":"B C 1B 2B 3B bB jB 4B cB","900":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"900":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"129":"OC"},I:{"900":"dB I H PC QC RC SC kB TC UC"},J:{"900":"E A"},K:{"129":"A B C bB jB cB","900":"T"},L:{"900":"H"},M:{"900":"S"},N:{"388":"A B"},O:{"900":"VC"},P:{"900":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"900":"gC"},R:{"900":"hC"},S:{"900":"iC"}},B:2,C:"CSS page-break properties"};
