module.exports={A:{A:{"2436":"J E F G A B lB"},B:{"260":"N O","2436":"C K L D M","8196":"P Q R U V W X Y Z a b c S d e H"},C:{"2":"mB dB I f J E F G A B C K L D M N O g h i oB pB","772":"0 1 j k l m n o p q r s t u v w x y z","4100":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB"},D:{"2":"I f J E F G A B C","2564":"0 1 2 3 K L D M N O g h i j k l m n o p q r s t u v w x y z","8196":"JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","10244":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB"},E:{"1":"C K L D cB xB yB zB","16":"sB hB","2308":"A B iB bB","2820":"I f J E F G tB uB vB wB"},F:{"2":"G B 0B 1B 2B 3B bB jB 4B","16":"C","516":"cB","2564":"D M N O g h i j k l m n o p q","8196":"6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","10244":"0 1 2 3 4 5 r s t u v w x y z"},G:{"1":"D GC HC IC JC KC LC MC NC","2":"hB 5B kB","2820":"F 6B 7B 8B 9B AC BC CC DC EC FC"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB","260":"H","2308":"TC UC"},J:{"2":"E","2308":"A"},K:{"2":"A B C bB jB","16":"cB","260":"T"},L:{"8196":"H"},M:{"1028":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"2052":"WC XC","2308":"I","8196":"YC ZC aC iB bC cC dC eC fC"},Q:{"10244":"gC"},R:{"2052":"hC"},S:{"4100":"iC"}},B:5,C:"Synchronous Clipboard API"};
