module.exports={A:{A:{"2":"J E F lB","8":"G","292":"A B"},B:{"1":"M N O P Q R U V W X Y Z a b c S d e H","292":"C K L D"},C:{"1":"FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O oB pB","8":"0 g h i j k l m n o p q r s t u v w x y z","584":"1 2 3 4 5 6 7 8 9 AB BB CB","1025":"DB EB"},D:{"1":"JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g h i j k l","8":"m n o p","200":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB","1025":"IB"},E:{"1":"B C K L D iB bB cB xB yB zB","2":"I f sB hB tB","8":"J E F G A uB vB wB"},F:{"1":"5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C D M N O g h i j k l m n o 0B 1B 2B 3B bB jB 4B cB","200":"0 1 2 3 4 p q r s t u v w x y z"},G:{"1":"D DC EC FC GC HC IC JC KC LC MC NC","2":"hB 5B kB 6B","8":"F 7B 8B 9B AC BC CC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC","8":"kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"292":"A B"},O:{"1":"VC"},P:{"1":"XC YC ZC aC iB bC cC dC eC fC","2":"WC","8":"I"},Q:{"1":"gC"},R:{"2":"hC"},S:{"1":"iC"}},B:4,C:"CSS Grid Layout (level 1)"};
