module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"D M N O P Q R U V W X Y Z a b c S d e H","2":"C K L"},C:{"1":"0 1 2 3 4 5 6 7 8 9 o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","33":"mB dB I f J E F G A B C K L D M N O g h i j k l m n oB pB"},D:{"1":"QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","33":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB"},E:{"1":"B C K L D bB cB xB yB zB","33":"I f J E F G A sB hB tB uB vB wB iB"},F:{"1":"C GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 4B cB","2":"G B 0B 1B 2B 3B bB jB","33":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"33":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"2":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"33":"gC"},R:{"2":"hC"},S:{"2":"iC"}},B:3,C:"CSS grab & grabbing cursors"};
