module.exports={A:{A:{"1":"G A B","132":"J E F lB"},B:{"1":"L D M N O P Q R U V W X Y Z a b c S d e H","260":"C K"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","4":"mB dB oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","4":"I"},E:{"1":"f J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB","4":"I sB hB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","260":"G B C 0B 1B 2B 3B bB jB 4B cB"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E","16":"A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"2":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"2":"gC"},R:{"2":"hC"},S:{"2":"iC"}},B:4,C:"CSS3 Cursors (original values)"};
