module.exports={A:{A:{"2":"J lB","2340":"E F G A B"},B:{"2":"C K L D M N O","1025":"P Q R U V W X Y Z a b c S d e H"},C:{"1":"d e H gB","2":"mB dB oB","513":"NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S","545":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T pB"},D:{"2":"0 1 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z","1025":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"A B C K L D iB bB cB xB yB zB","2":"I f sB hB tB","164":"J","4644":"E F G uB vB wB"},F:{"2":"G B D M N O g h i j k l m n o 0B 1B 2B 3B bB jB","545":"C 4B cB","1025":"0 1 2 3 4 5 6 7 8 9 p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"1":"D CC DC EC FC GC HC IC JC KC LC MC NC","2":"hB 5B kB","4260":"6B 7B","4644":"F 8B 9B AC BC"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB TC UC","1025":"H"},J:{"2":"E","4260":"A"},K:{"2":"A B bB jB","545":"C cB","1025":"T"},L:{"1025":"H"},M:{"545":"S"},N:{"2340":"A B"},O:{"1":"VC"},P:{"1025":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1025":"gC"},R:{"1025":"hC"},S:{"4097":"iC"}},B:7,C:"Crisp edges/pixelated images"};
