module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"N O P Q R U V W X Y Z a b c S d e H","2":"C K L D M"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB oB pB","4609":"LB MB T NB OB PB QB RB SB","4674":"fB","5698":"KB","7490":"EB FB GB HB IB","7746":"JB eB","8705":"TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB"},D:{"1":"PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB","4097":"OB","4290":"eB KB fB","6148":"LB MB T NB"},E:{"1":"D zB","2":"I f J E F G A sB hB tB uB vB wB iB","4609":"B C bB cB","8193":"K L xB yB"},F:{"1":"FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z 0B 1B 2B 3B bB jB 4B cB","4097":"EB","6148":"AB BB CB DB"},G:{"1":"D IC JC KC LC MC NC","2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC","4097":"EC FC GC HC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"4097":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"2":"I WC XC YC","4097":"ZC aC iB bC cC dC eC fC"},Q:{"4097":"gC"},R:{"2":"hC"},S:{"2":"iC"}},B:5,C:"Variable fonts"};
