module.exports={A:{A:{"132":"J E F G A B lB"},B:{"1":"P Q R U V W X Y Z a b c S d e H","132":"C K L D M N O"},C:{"1":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","33":"0 1 2 3 4 5 6 7 8 9 N O g h i j k l m n o p q r s t u v w x y z AB","132":"mB dB I f J E F G oB pB","292":"A B C K L D M"},D:{"1":"9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","132":"I f J E F G A B C K L D M","548":"0 1 2 3 4 5 6 7 8 N O g h i j k l m n o p q r s t u v w x y z"},E:{"132":"I f J E F sB hB tB uB vB","548":"G A B C K L D wB iB bB cB xB yB zB"},F:{"132":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B bB jB 4B cB"},G:{"132":"F hB 5B kB 6B 7B 8B 9B","548":"D AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"16":"OC"},I:{"1":"H","16":"dB I PC QC RC SC kB TC UC"},J:{"16":"E A"},K:{"1":"T","16":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"132":"A B"},O:{"16":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","16":"I"},Q:{"16":"gC"},R:{"16":"hC"},S:{"33":"iC"}},B:4,C:"CSS unicode-bidi property"};
