module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"L D M N O P Q R U V W X Y Z a b c S d e H","2":"C K"},C:{"1":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g"},E:{"1":"K L D cB xB yB zB","2":"I f J E F G A B C sB hB tB uB vB wB iB bB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 B C N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R bB jB 4B cB","2":"G D M 0B 1B 2B 3B"},G:{"2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC","129":"D HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H TC UC","2":"dB I PC QC RC SC kB"},J:{"1":"E A"},K:{"1":"A B C T bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"2":"iC"}},B:1,C:"Color input type"};
