module.exports={A:{A:{"644":"J E F G lB","772":"A B"},B:{"1":"O P Q R U V W X Y Z a b c S d e H","260":"C K L D M N"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB oB pB","8":"mB dB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"I f J E F G A B C K L D sB hB tB uB vB wB iB bB cB xB yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R cB","8":"G B 0B 1B 2B 3B bB jB 4B"},G:{"1":"D","2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB TC UC","1025":"H"},J:{"2":"E A"},K:{"1":"cB","8":"A B C bB jB","1025":"T"},L:{"1025":"H"},M:{"2":"S"},N:{"1":"A B"},O:{"2":"VC"},P:{"2":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"2":"hC"},S:{"2":"iC"}},B:1,C:"Drag and Drop"};
