module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"V W X Y Z a b c S d e H","2":"C K L D M N O","260":"P Q R U"},C:{"1":"R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t oB pB","260":"eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB","516":"8 9 AB BB CB DB EB FB GB HB IB JB","580":"0 1 2 3 4 5 6 7 u v w x y z","2049":"XB YB ZB aB P Q"},D:{"1":"V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w","132":"x y z","260":"0 1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U"},E:{"1":"D zB","2":"I f J E F G A sB hB tB uB vB wB iB","1090":"B C K bB cB","2049":"L xB yB"},F:{"1":"TB UB VB WB XB YB ZB aB P Q R","2":"G B C D M N O g h i j 0B 1B 2B 3B bB jB 4B cB","132":"k l m","260":"0 1 2 3 4 5 6 7 8 9 n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB"},G:{"2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC","1090":"EC FC GC HC IC JC KC","2049":"D LC MC NC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"260":"VC"},P:{"260":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"260":"gC"},R:{"260":"hC"},S:{"516":"iC"}},B:5,C:"Web Animations API"};
