module.exports={A:{A:{"2":"G A B lB","8":"J E F"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2":"C K L D M N O"},C:{"1":"AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB","8":"0 1 2 3 4 5 6 7 dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z oB pB","194":"8 9"},D:{"1":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","8":"I f J E F G A B","257":"g h i j k l m n o p q r s t u v w","769":"C K L D M N O"},E:{"1":"C K L D cB xB yB zB","8":"I f sB hB tB","257":"J E F G A uB vB wB","1025":"B iB bB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"C bB jB 4B cB","8":"G B 0B 1B 2B 3B"},G:{"1":"F D 7B 8B 9B AC BC FC GC HC IC JC KC LC MC NC","8":"hB 5B kB 6B","1025":"CC DC EC"},H:{"8":"OC"},I:{"1":"I H SC kB TC UC","8":"dB PC QC RC"},J:{"1":"A","8":"E"},K:{"1":"T","8":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"769":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:1,C:"Details & Summary elements"};
