module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"K L D M N O P Q R U V W X Y Z a b c S d e H","132":"C"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB oB pB","1090":"EB FB GB HB","2052":"IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S","4100":"d e H gB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g","2052":"h i j k l"},E:{"2":"I f J E F G A B C K L sB hB tB uB vB wB iB bB cB xB","4100":"D yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B bB jB 4B cB"},G:{"2":"hB 5B kB","260":"F D 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H TC UC","2":"dB PC QC RC","514":"I SC kB"},J:{"1":"A","2":"E"},K:{"1":"A B C T bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"2052":"iC"}},B:1,C:"Date and time input types"};
