module.exports={A:{A:{"16":"J E lB","132":"F G A B"},B:{"132":"C K L D M N O","322":"P Q R U V W X Y Z a b c S d e H"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB oB pB","1025":"GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","1602":"FB"},D:{"2":"0 1 2 3 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z","322":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"2":"I f J E F G A B C K L D sB hB tB uB vB wB iB bB cB xB yB zB"},F:{"2":"G B C D M N O g h i j k l m n o p q 0B 1B 2B 3B bB jB 4B cB","322":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB TC UC","322":"H"},J:{"2":"E A"},K:{"2":"A B C bB jB cB","322":"T"},L:{"322":"H"},M:{"1025":"S"},N:{"132":"A B"},O:{"2":"VC"},P:{"2":"I","322":"WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"322":"gC"},R:{"322":"hC"},S:{"2":"iC"}},B:5,C:"CSS text-justify"};
