module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"O P Q R U V W X Y Z a b c S d e H","2":"C K L D M N"},C:{"1":"NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB oB pB","8":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T"},D:{"1":"0 1 2 3 4 5 6 7 8 9 t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f","8":"J E F","132":"G A B C K L D M N O g h i j","260":"k l m n o p q r s"},E:{"2":"I f J E F G A B C K sB hB tB uB vB wB iB bB cB xB","516":"L D yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G 0B 1B 2B","8":"B 3B","132":"bB jB 4B","260":"C D M N O cB"},G:{"1":"D MC NC","2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC"},H:{"1":"OC"},I:{"1":"H kB TC UC","2":"dB PC QC RC","132":"I SC"},J:{"2":"E A"},K:{"1":"C T bB jB cB","2":"A","132":"B"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"8":"iC"}},B:7,C:"WebP image format"};
