module.exports={A:{A:{"2":"J E F G A B lB"},B:{"2":"C K L D M N O","164":"P Q R U V W X Y Z a b c S d e H"},C:{"1":"7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"0 1 2 3 4 5 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z oB pB","322":"6"},D:{"2":"I f J E F G A B C K L D M N O g h i j k l","164":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"F G A B C K L D vB wB iB bB cB xB yB zB","2":"I f J sB hB tB","164":"E uB"},F:{"2":"G B C 0B 1B 2B 3B bB jB 4B cB","164":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"1":"F D 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","2":"hB 5B kB 6B 7B"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB","164":"H TC UC"},J:{"2":"E","164":"A"},K:{"2":"A B C bB jB cB","164":"T"},L:{"164":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"164":"VC"},P:{"164":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"164":"gC"},R:{"164":"hC"},S:{"1":"iC"}},B:4,C:"text-emphasis styling"};
