module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"L D M N O","2":"C K","257":"P Q R U V W X Y Z a b c S d e H"},C:{"1":"AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r oB pB","194":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z"},D:{"1":"0 1 2 3 4 5 6 7 8 9 u v w x y z AB BB CB DB EB FB","2":"I f J E F G A B C K L D M N O g h i j k l m n o p q r s t","257":"GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"E F G A B C K L D vB wB iB bB cB xB yB zB","2":"I f J sB hB tB uB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB","2":"G B C D M N O g h i j k l m n 0B 1B 2B 3B bB jB 4B cB","257":"T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"1":"F D 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","2":"hB 5B kB 6B 7B"},H:{"2":"OC"},I:{"2":"dB I H PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"2":"A B C T bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","2":"I"},Q:{"1":"gC"},R:{"2":"hC"},S:{"1":"iC"}},B:7,C:"Speech Synthesis API"};
