module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"L D M N O P Q R U V W X Y Z a b c S d e H","2":"C K"},C:{"1":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I","36":"f J E F G A B C K L D M N O g h i"},E:{"1":"J E F G A B C K L D uB vB wB iB bB cB xB yB zB","2":"I f sB hB tB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C D M N O g h i j k l 0B 1B 2B 3B bB jB 4B cB"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB","36":"H TC UC"},J:{"1":"A","2":"E"},K:{"2":"A B C bB jB cB","36":"T"},L:{"513":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"36":"I","258":"WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"2":"gC"},R:{"258":"hC"},S:{"1":"iC"}},B:1,C:"Web Notifications"};
