module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"a b c S d e H","2":"C K L D M N O","2052":"Y Z","3588":"P Q R U V W X"},C:{"1":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB","164":"0 1 dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z oB pB"},D:{"1":"a b c S d e H gB qB rB","292":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB","2052":"Y Z","3588":"RB SB TB UB VB WB XB YB ZB aB P Q R U V W X"},E:{"1":"D zB","292":"I f J E F G A B C sB hB tB uB vB wB iB bB","2052":"yB","3588":"K L cB xB"},F:{"1":"YB ZB aB P Q R","2":"G B C 0B 1B 2B 3B bB jB 4B cB","292":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB","2052":"WB XB","3588":"HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB"},G:{"1":"D","292":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC","2052":"NC","3588":"HC IC JC KC LC MC"},H:{"2":"OC"},I:{"1":"H","292":"dB I PC QC RC SC kB TC UC"},J:{"292":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"292":"VC"},P:{"1":"fC","292":"I WC XC YC ZC aC","3588":"iB bC cC dC eC"},Q:{"3588":"gC"},R:{"3588":"hC"},S:{"3588":"iC"}},B:5,C:"CSS Logical Properties"};
