module.exports={A:{A:{"1":"B","2":"J E F G lB","164":"A"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f oB pB","8":"0 1 J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z","328":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB"},D:{"1":"GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g h i","8":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w x y z AB BB CB","584":"DB EB FB"},E:{"1":"K L D xB yB zB","2":"I f J sB hB tB","8":"E F G A B C uB vB wB iB bB","1096":"cB"},F:{"1":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C 0B 1B 2B 3B bB jB 4B cB","8":"D M N O g h i j k l m n o p q r s t u v w x y z","584":"0 1 2"},G:{"1":"D JC KC LC MC NC","8":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC","6148":"IC"},H:{"2":"OC"},I:{"1":"H","8":"dB I PC QC RC SC kB TC UC"},J:{"8":"E A"},K:{"1":"T","2":"A","8":"B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","36":"A"},O:{"8":"VC"},P:{"1":"XC YC ZC aC iB bC cC dC eC fC","2":"WC","8":"I"},Q:{"1":"gC"},R:{"2":"hC"},S:{"328":"iC"}},B:2,C:"Pointer events"};
