module.exports={A:{A:{"2":"J E F G lB","8":"A B"},B:{"1":"P","2":"Q R U V W X Y Z a b c S d e H","8":"C K L D M N O"},C:{"2":"mB dB I f J E F G A B C K L D M N O g h i j eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB oB pB","66":"k l m n o p q","72":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P","2":"I f J E F G A B C K L D M N O g h i j k l m n Q R U V W X Y Z a b c S d e H gB qB rB","66":"o p q r s t"},E:{"2":"I f sB hB tB","8":"J E F G A B C K L D uB vB wB iB bB cB xB yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB","2":"G B C PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B bB jB 4B cB","66":"D M N O g"},G:{"2":"hB 5B kB 6B 7B","8":"F D 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"UC","2":"dB I H PC QC RC SC kB TC"},J:{"2":"E A"},K:{"2":"A B C T bB jB cB"},L:{"2":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC","2":"dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"72":"iC"}},B:7,C:"Custom Elements (deprecated V0 spec)"};
