module.exports={A:{A:{"1":"B","2":"J E F G A lB"},B:{"1":"L D M N O P Q R U V W X Y Z a b c S d e H","129":"C K"},C:{"1":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB","260":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB","804":"I f J E F G A B C K L oB pB"},D:{"1":"HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","260":"CB DB EB FB GB","388":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB","1412":"D M N O g h i j k l m n o p q","1956":"I f J E F G A B C K L"},E:{"129":"A B C K L D wB iB bB cB xB yB zB","1412":"J E F G uB vB","1956":"I f sB hB tB"},F:{"1":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G 0B 1B","260":"0 1 2 3 z","388":"D M N O g h i j k l m n o p q r s t u v w x y","1796":"2B 3B","1828":"B C bB jB 4B cB"},G:{"129":"D BC CC DC EC FC GC HC IC JC KC LC MC NC","1412":"F 7B 8B 9B AC","1956":"hB 5B kB 6B"},H:{"1828":"OC"},I:{"1":"H","388":"TC UC","1956":"dB I PC QC RC SC kB"},J:{"1412":"A","1924":"E"},K:{"1":"T","2":"A","1828":"B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","2":"A"},O:{"388":"VC"},P:{"1":"YC ZC aC iB bC cC dC eC fC","260":"WC XC","388":"I"},Q:{"260":"gC"},R:{"260":"hC"},S:{"260":"iC"}},B:4,C:"CSS3 Border images"};
