module.exports={A:{A:{"1":"A B","2":"J E lB","132":"F G"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"I f J E F G A B C K L D sB hB tB uB vB wB iB bB cB xB yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R bB jB 4B cB","2":"G 0B 1B 2B 3B"},G:{"1":"hB 5B kB 6B","513":"F D 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"4097":"OC"},I:{"1025":"dB I H PC QC RC SC kB TC UC"},J:{"258":"E A"},K:{"2":"A","258":"B C bB jB cB","1025":"T"},L:{"1025":"H"},M:{"2049":"S"},N:{"258":"A B"},O:{"258":"VC"},P:{"1025":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1025":"hC"},S:{"1":"iC"}},B:1,C:"Basic console logging functions"};
