module.exports={A:{A:{"2":"J E F G A B lB"},B:{"2":"C K L D M N O","2052":"P Q R U V W X Y Z a b c S d e H"},C:{"2":"mB dB I f oB pB","1028":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","1060":"J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w"},D:{"2":"I f J E F G A B C K L D M N O g h i j k l m","226":"0 1 2 3 4 5 6 7 8 9 n o p q r s t u v w x y z AB BB CB DB EB FB GB HB","2052":"IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"2":"I f J E sB hB tB uB","772":"K L D cB xB yB zB","804":"F G A B C wB iB bB","1316":"vB"},F:{"2":"G B C D M N O g h i j k l m n o p q r s t u v 0B 1B 2B 3B bB jB 4B cB","226":"0 1 2 3 4 w x y z","2052":"5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"2":"hB 5B kB 6B 7B 8B","292":"F D 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"2052":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2052":"VC"},P:{"2":"I WC XC","2052":"YC ZC aC iB bC cC dC eC fC"},Q:{"2":"gC"},R:{"1":"hC"},S:{"1028":"iC"}},B:4,C:"text-decoration styling"};
