module.exports={A:{A:{"2":"J E F G A B lB"},B:{"2":"C K L D M N O","1537":"P Q R U V W X Y Z a b c S d e H"},C:{"2":"mB","932":"0 1 2 3 4 5 6 7 8 9 dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB oB pB","2308":"OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB"},D:{"2":"I f J E F G A B C K L D M N O g h i","545":"0 1 2 3 4 5 6 j k l m n o p q r s t u v w x y z","1537":"7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"2":"I f J sB hB tB","516":"B C K L D bB cB xB yB zB","548":"G A wB iB","676":"E F uB vB"},F:{"2":"G B C 0B 1B 2B 3B bB jB 4B cB","513":"v","545":"D M N O g h i j k l m n o p q r s t","1537":"0 1 2 3 4 5 6 7 8 9 u w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"2":"hB 5B kB 6B 7B","516":"D MC NC","548":"AC BC CC DC EC FC GC HC IC JC KC LC","676":"F 8B 9B"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB","545":"TC UC","1537":"H"},J:{"2":"E","545":"A"},K:{"2":"A B C bB jB cB","1537":"T"},L:{"1537":"H"},M:{"2308":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"545":"I","1537":"WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"545":"gC"},R:{"1537":"hC"},S:{"932":"iC"}},B:5,C:"Intrinsic & Extrinsic Sizing"};
