module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"M N O P Q R U V W X Y Z a b c S d e H","2":"C K L D"},C:{"1":"CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB oB pB"},D:{"1":"HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"0 1 2 3 4 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z","16":"5 6 7","388":"8 9 AB BB CB DB EB FB GB"},E:{"1":"K L D xB yB zB","2":"I f J E F G A sB hB tB uB vB wB iB","516":"B C bB cB"},F:{"1":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"0 1 2 G B C D M N O g h i j k l m n o p q r s t u v w x y z 0B 1B 2B 3B bB jB 4B cB"},G:{"1":"D EC FC GC HC IC JC KC LC MC NC","2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC"},H:{"2":"OC"},I:{"1":"H","2":"PC QC RC","16":"dB I SC kB TC UC"},J:{"1":"A","2":"E"},K:{"1":"T cB","16":"A B C bB jB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","129":"I"},Q:{"1":"gC"},R:{"1":"hC"},S:{"2":"iC"}},B:6,C:"FLAC audio format"};
