module.exports={A:{A:{"2":"G A B lB","8":"J E F"},B:{"2":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB oB pB"},D:{"1":"I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y","2":"CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","130":"0 1 2 3 4 5 6 7 8 9 z AB BB"},E:{"1":"I f J E F G A B C K L D hB tB uB vB wB iB bB cB xB yB zB","2":"sB"},F:{"1":"G B C D M N O g h i j k l 0B 1B 2B 3B bB jB 4B cB","2":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","130":"m n o p q r s t u v w x"},G:{"1":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"258":"OC"},I:{"1":"dB I SC kB TC UC","2":"H PC QC RC"},J:{"1":"E A"},K:{"1":"A B C bB jB cB","2":"T"},L:{"130":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"1":"I","130":"WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"2":"gC"},R:{"130":"hC"},S:{"2":"iC"}},B:2,C:"SVG fonts"};
