module.exports={A:{A:{"2":"J E F A B lB","16":"G"},B:{"2":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB oB pB","16":"I f"},D:{"2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","16":"B C"},E:{"2":"I J sB hB tB","16":"f E F G A B C K L D uB vB wB iB bB cB xB yB zB"},F:{"2":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B jB 4B cB","16":"bB"},G:{"2":"hB 5B kB 6B 7B","16":"F D 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I H PC QC SC kB TC UC","16":"RC"},J:{"2":"A","16":"E"},K:{"2":"A B C T bB jB cB"},L:{"2":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"2":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"2":"gC"},R:{"2":"hC"},S:{"2":"iC"}},B:7,C:"Test feature - updated"};
