module.exports={A:{A:{"2":"J E F G lB","8":"A B"},B:{"1":"P Q R U V W X Y Z a b c S d e H","8":"C K L D M N O"},C:{"1":"MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q oB pB","8":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB","456":"BB CB DB EB FB GB HB IB JB","712":"eB KB fB LB"},D:{"1":"PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB","8":"DB EB","132":"FB GB HB IB JB eB KB fB LB MB T NB OB"},E:{"2":"I f J E sB hB tB uB vB","8":"F G A wB","132":"B C K L D iB bB cB xB yB zB"},F:{"1":"T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"0 1 G B C D M N O g h i j k l m n o p q r s t u v w x y z 0B 1B 2B 3B bB jB 4B cB","132":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB"},G:{"2":"F hB 5B kB 6B 7B 8B 9B AC BC CC","132":"D DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"XC YC ZC aC iB bC cC dC eC fC","2":"I","132":"WC"},Q:{"132":"gC"},R:{"132":"hC"},S:{"8":"iC"}},B:1,C:"Custom Elements (V1)"};
