module.exports={A:{A:{"2":"J E F G lB","8":"A B"},B:{"1":"P Q R U V W X Y Z a b c S d e H","578":"C K L D M N O"},C:{"1":"O g h i j k l DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB oB pB","4":"I f J E F G A B C K L D M N","194":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g h i"},E:{"2":"I f J E F G A B C K L D sB hB tB uB vB wB iB bB cB xB yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C 0B 1B 2B 3B bB jB 4B cB"},G:{"1":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"dB I H PC QC RC SC kB TC UC"},J:{"1":"E A"},K:{"1":"B C T bB jB cB","2":"A"},L:{"1":"H"},M:{"1":"S"},N:{"8":"A","260":"B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"2":"iC"}},B:2,C:"Touch events"};
