module.exports={A:{A:{"2":"J E F G lB","33":"A B"},B:{"33":"C K L D M N O","132":"P Q R U V W X Y","260":"Z a b c S d e H"},C:{"1":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f oB pB","33":"0 1 2 3 J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z"},D:{"1":"Z a b c S d e H gB qB rB","2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB","132":"GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y"},E:{"2":"I f sB hB","33":"J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB"},F:{"2":"0 1 2 G B C D M N O g h i j k l m n o p q r s t u v w x y z 0B 1B 2B 3B bB jB 4B cB","132":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"2":"hB 5B","33":"F D kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"4":"VC"},P:{"1":"XC YC ZC aC iB bC cC dC eC fC","2":"I","132":"WC"},Q:{"2":"gC"},R:{"132":"hC"},S:{"1":"iC"}},B:5,C:"CSS Hyphenation"};
