module.exports={A:{A:{"1":"G A B","16":"lB","260":"J E F"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","132":"0 1 2 3 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z oB pB","2180":"4 5 6 7 8 9 AB BB CB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","16":"I f J E F G A B C K L"},E:{"1":"J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB","16":"I f sB hB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","132":"G B C 0B 1B 2B 3B bB jB 4B cB"},G:{"16":"kB","132":"hB 5B","516":"F D 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H TC UC","16":"dB I PC QC RC SC","1025":"kB"},J:{"1":"A","16":"E"},K:{"1":"T","16":"A B C bB jB","132":"cB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","16":"A"},O:{"1025":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"2180":"iC"}},B:5,C:"Selection API"};
