module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2":"C K L D M N O"},C:{"1":"c S d e H gB","2":"mB dB oB pB","33":"EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b","164":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB"},D:{"1":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g h","132":"0 1 2 i j k l m n o p q r s t u v w x y z"},E:{"1":"L D xB yB zB","2":"I f J sB hB tB","132":"E F G A B C K uB vB wB iB bB cB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G 0B 1B 2B","132":"D M N O g h i j k l m n o p","164":"B C 3B bB jB 4B cB"},G:{"1":"D LC MC NC","2":"hB 5B kB 6B 7B","132":"F 8B 9B AC BC CC DC EC FC GC HC IC JC KC"},H:{"164":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB","132":"TC UC"},J:{"132":"E A"},K:{"1":"T","2":"A","164":"B C bB jB cB"},L:{"1":"H"},M:{"33":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"164":"iC"}},B:5,C:"CSS3 tab-size"};
