module.exports={A:{A:{"1":"A B","16":"lB","900":"J E F G"},B:{"1":"P Q R U V W X Y Z a b c S d e H","1025":"C K L D M N O"},C:{"1":"CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","900":"mB dB oB pB","1025":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB","16":"f sB","900":"I hB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","16":"G","132":"B C 0B 1B 2B 3B bB jB 4B cB"},G:{"1":"D 5B kB 6B 7B 8B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","16":"hB","2052":"F 9B"},H:{"132":"OC"},I:{"1":"dB I RC SC kB TC UC","16":"PC QC","4097":"H"},J:{"1":"E A"},K:{"132":"A B C bB jB cB","4097":"T"},L:{"4097":"H"},M:{"4097":"S"},N:{"1":"A B"},O:{"1":"VC"},P:{"4097":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1025":"iC"}},B:1,C:"maxlength attribute for input and textarea elements"};
