module.exports={A:{A:{"2":"J E F G A lB","130":"B"},B:{"1":"a b c S d e H","16":"C K","260":"L D","1028":"P Q R U V W X Y Z","5124":"M N O"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB oB pB","6148":"NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","6722":"IB JB eB KB fB LB MB T"},D:{"1":"a b c S d e H gB qB rB","2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB","260":"DB EB FB GB HB IB JB","1028":"eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z"},E:{"2":"I f J E F G sB hB tB uB vB wB","1028":"D yB zB","3076":"A B C K L iB bB cB xB"},F:{"1":"YB ZB aB P Q R","2":"G B C D M N O g h i j k l m n o p q r s t u v w x y z 0B 1B 2B 3B bB jB 4B cB","260":"0 1 2 3 4 5 6","1028":"7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB"},G:{"2":"F hB 5B kB 6B 7B 8B 9B AC BC","16":"CC","1028":"D DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"6148":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"1":"fC","2":"I WC XC","1028":"YC ZC aC iB bC cC dC eC"},Q:{"1028":"gC"},R:{"2":"hC"},S:{"2":"iC"}},B:1,C:"Streams"};
