module.exports={A:{A:{"2":"lB","8":"J E F","260":"G A B"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB","132":"dB oB pB","260":"I f J E F G A B C K L D M N O g h"},D:{"1":"0 1 2 3 4 5 6 7 8 9 n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","132":"I f","260":"J E F G A B C K L D M N O g h i j k l m"},E:{"1":"E F G A B C K L D uB vB wB iB bB cB xB yB zB","132":"I sB hB","260":"f J tB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","132":"G B 0B 1B 2B 3B","260":"C bB jB 4B cB"},G:{"1":"F D 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","132":"hB","260":"5B kB 6B 7B"},H:{"132":"OC"},I:{"1":"H TC UC","132":"PC","260":"dB I QC RC SC kB"},J:{"260":"E A"},K:{"1":"T","132":"A","260":"B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"260":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:1,C:"HTML5 semantic elements"};
