module.exports={A:{A:{"132":"J E F G A B lB"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w oB pB","322":"0 1 x y z"},D:{"1":"9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J","16":"E","33":"0 1 2 3 4 5 6 7 8 F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z"},E:{"1":"B C K L D bB cB xB yB zB","2":"I sB hB","16":"f","33":"J E F G A tB uB vB wB iB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C 0B 1B 2B 3B bB jB 4B cB","33":"D M N O g h i j k l m n o p q r s t u v"},G:{"1":"D EC FC GC HC IC JC KC LC MC NC","16":"hB 5B kB","33":"F 6B 7B 8B 9B AC BC CC DC"},H:{"2":"OC"},I:{"1":"H","2":"PC QC RC","33":"dB I SC kB TC UC"},J:{"33":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"36":"A B"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","33":"I"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:4,C:"CSS writing-mode property"};
