module.exports={A:{A:{"1":"B","4":"J E F G A lB"},B:{"1":"C K L D M","129":"N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB","4":"mB dB I f oB pB","129":"CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB"},D:{"1":"6 7 8 9 AB BB CB DB EB FB","4":"I f J","129":"0 1 2 3 4 5 E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"4":"I f sB hB","129":"J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB"},F:{"1":"0 1 2 C t u v w x y z bB jB 4B cB","4":"G B 0B 1B 2B 3B","129":"3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"4":"hB 5B kB","129":"F D 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"4":"OC"},I:{"4":"PC QC RC","129":"dB I H SC kB TC UC"},J:{"129":"E A"},K:{"1":"C bB jB cB","4":"A B","129":"T"},L:{"129":"H"},M:{"129":"S"},N:{"1":"B","4":"A"},O:{"129":"VC"},P:{"129":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"129":"hC"},S:{"1":"iC"}},B:1,C:"dataset & data-* attributes"};
