module.exports={A:{A:{"2":"J E F lB","257":"G A B"},B:{"1":"C K L D M N O","513":"P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s oB pB"},D:{"2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB","513":"TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"1":"L D yB zB","2":"I f J E F G A sB hB tB uB vB wB iB","129":"B C K bB cB xB"},F:{"2":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB 0B 1B 2B 3B bB jB 4B cB","513":"JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"1":"D EC FC GC HC IC JC KC LC MC NC","2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"16":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"16":"A B"},O:{"1":"VC"},P:{"1":"iB bC cC dC eC fC","2":"I WC XC YC ZC aC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:6,C:"COLR/CPAL(v0) Font Formats"};
