module.exports={A:{A:{"2":"J E F G A B lB"},B:{"2":"C K L D M N","260":"P Q R U V W X Y Z a b c S d e H","3138":"O"},C:{"1":"FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB","132":"0 1 2 3 4 5 6 7 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z oB pB","644":"8 9 AB BB CB DB EB"},D:{"2":"I f J E F G A B C K L D M N O g h i j k","260":"GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","292":"0 1 2 3 4 5 6 7 8 9 l m n o p q r s t u v w x y z AB BB CB DB EB FB"},E:{"2":"I f J sB hB tB uB","292":"E F G A B C K L D vB wB iB bB cB xB yB zB"},F:{"2":"G B C 0B 1B 2B 3B bB jB 4B cB","260":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","292":"0 1 2 D M N O g h i j k l m n o p q r s t u v w x y z"},G:{"2":"hB 5B kB 6B 7B","292":"F D 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB","260":"H","292":"TC UC"},J:{"2":"E A"},K:{"2":"A B C bB jB cB","260":"T"},L:{"260":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"292":"VC"},P:{"292":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"292":"gC"},R:{"260":"hC"},S:{"644":"iC"}},B:4,C:"CSS clip-path property (for HTML)"};
