module.exports={A:{A:{"4":"J E F G A B lB"},B:{"4":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","8":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y oB pB"},D:{"4":"0 1 2 3 4 5 6 7 8 9 f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","8":"I"},E:{"4":"f J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB","8":"I sB hB"},F:{"4":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","8":"G B C 0B 1B 2B 3B bB jB 4B cB"},G:{"4":"F D 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC","8":"hB 5B kB"},H:{"8":"OC"},I:{"4":"dB I H SC kB TC UC","8":"PC QC RC"},J:{"4":"A","8":"E"},K:{"4":"T","8":"A B C bB jB cB"},L:{"4":"H"},M:{"1":"S"},N:{"4":"A B"},O:{"4":"VC"},P:{"4":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"4":"gC"},R:{"4":"hC"},S:{"1":"iC"}},B:1,C:"Ruby annotation"};
