module.exports={A:{A:{"2":"J E F G A lB","548":"B"},B:{"1":"P Q R U V W X Y Z a b c S d e H","516":"C K L D M N O"},C:{"1":"T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G oB pB","676":"0 1 2 3 4 5 6 7 A B C K L D M N O g h i j k l m n o p q r s t u v w x y z","1700":"8 9 AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB"},D:{"1":"TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L","676":"D M N O g","804":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB"},E:{"2":"I f sB hB","676":"tB","804":"J E F G A B C K L D uB vB wB iB bB cB xB yB zB"},F:{"1":"T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R cB","2":"G B C 0B 1B 2B 3B bB jB 4B","804":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC","2052":"GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"2":"dB I H PC QC RC SC kB TC UC"},J:{"2":"E","292":"A"},K:{"2":"A B C T bB jB cB"},L:{"804":"H"},M:{"1":"S"},N:{"2":"A","548":"B"},O:{"804":"VC"},P:{"1":"iB bC cC dC eC fC","804":"I WC XC YC ZC aC"},Q:{"804":"gC"},R:{"804":"hC"},S:{"1":"iC"}},B:1,C:"Full Screen API"};
