module.exports={A:{A:{"2":"J E F G A B lB"},B:{"2":"C K L D M N O P Q","516":"R U V W X Y Z a b c S d e H"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB oB pB"},D:{"2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z","130":"O g h i j k l","1028":"a b c S d e H gB qB rB"},E:{"1":"L D yB zB","2":"I f J E F G A B C sB hB tB uB vB wB iB bB","2049":"K cB xB"},F:{"2":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 0B 1B 2B 3B bB jB 4B cB"},G:{"1":"D MC NC","2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC","2049":"HC IC JC KC LC"},H:{"2":"OC"},I:{"2":"dB I PC QC RC SC kB TC","258":"H UC"},J:{"2":"E A"},K:{"2":"A B C bB jB cB","258":"T"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"1":"ZC aC iB bC cC dC eC fC","2":"I","258":"WC XC YC"},Q:{"2":"gC"},R:{"16":"hC"},S:{"2":"iC"}},B:5,C:"Web Share API"};
