module.exports={A:{A:{"2":"J E F G A B lB"},B:{"2":"C K L D M N O","16":"P Q R U V W X Y Z a b c S d e H"},C:{"2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e oB pB","16":"H gB"},D:{"2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H","16":"gB qB rB"},E:{"1":"C K cB","2":"I f J E F G A B sB hB tB uB vB wB iB bB","16":"L D xB yB zB"},F:{"2":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB 0B 1B 2B 3B bB jB 4B cB","16":"EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"2":"F D hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"16":"OC"},I:{"2":"dB I PC QC RC SC kB TC UC","16":"H"},J:{"2":"E","16":"A"},K:{"2":"A B C bB jB cB","16":"T"},L:{"16":"H"},M:{"16":"S"},N:{"2":"A","16":"B"},O:{"16":"VC"},P:{"2":"I WC XC","16":"YC ZC aC iB bC cC dC eC fC"},Q:{"16":"gC"},R:{"16":"hC"},S:{"2":"iC"}},B:1,C:"Password Rules"};
