module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"K L D M N O P Q R U V W X Y Z a b c S d e H","2":"C"},C:{"1":"aB P Q R nB U V W X Y Z a b c S d e H gB","16":"mB","33":"0 1 2 3 4 5 6 7 8 9 dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","16":"I f J E F G A B C K L","132":"D M N O g h i j k l m n o p q r s t u v w"},E:{"1":"G A B C K L D wB iB bB cB xB yB zB","16":"sB hB","132":"I f J E F tB uB vB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","16":"G B 0B 1B 2B 3B bB","132":"C D M N O g h i j jB 4B cB"},G:{"1":"D AC BC CC DC EC FC GC HC IC JC KC LC MC NC","16":"hB 5B","132":"F kB 6B 7B 8B 9B"},H:{"2":"OC"},I:{"1":"H","16":"PC QC","132":"dB I RC SC kB TC UC"},J:{"1":"A","132":"E"},K:{"1":"T","2":"A B bB","132":"C jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"33":"iC"}},B:1,C:"CSS :read-only and :read-write selectors"};
