module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2":"C K L D M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p oB pB"},D:{"1":"AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"0 1 2 3 4 5 6 7 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z","194":"8 9"},E:{"1":"D yB zB","2":"I f J E F G A B C sB hB tB uB vB wB iB bB","322":"K L cB xB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C D M N O g h i j k l m n o p q r s t u 0B 1B 2B 3B bB jB 4B cB","194":"v w"},G:{"1":"D NC","2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC","578":"GC HC IC JC KC LC MC"},H:{"2":"OC"},I:{"2":"dB I H PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"2":"A B C T bB jB cB"},L:{"1":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","2":"I"},Q:{"1":"gC"},R:{"2":"hC"},S:{"1":"iC"}},B:5,C:"MediaRecorder API"};
