module.exports={A:{A:{"2":"J E F lB","260":"G A B"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB I f J E F G A B C K L oB pB"},D:{"1":"BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w","132":"0 1 2 3 4 5 6 7 8 9 x y z AB"},E:{"1":"C K L D bB cB xB yB zB","2":"I f J E G A B sB hB tB uB wB iB","132":"F vB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R cB","2":"D M N O g h i j","4":"B C 1B 2B 3B bB jB 4B","16":"G 0B","132":"k l m n o p q r s t u v w x"},G:{"1":"D FC GC HC IC JC KC LC MC NC","2":"hB 5B kB 6B 7B 8B AC BC CC DC EC","132":"F 9B"},H:{"1":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E","132":"A"},K:{"1":"T cB","4":"A B C bB jB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"A B"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","132":"I"},Q:{"1":"gC"},R:{"132":"hC"},S:{"1":"iC"}},B:4,C:"SVG fragment identifiers"};
