module.exports={A:{A:{"2":"J E F lB","260":"G A B"},B:{"132":"P Q R U V W X Y Z a b c S d e H","260":"C K L D M N O"},C:{"2":"mB dB I f oB pB","260":"0 1 2 3 4 5 6 7 8 9 J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB"},D:{"16":"I f J E F G A B C K L","132":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB"},E:{"16":"sB hB","132":"I f J E F G A B C K L D tB uB vB wB iB bB cB xB yB zB"},F:{"1":"C 4B cB","2":"G 0B 1B 2B 3B","16":"B bB jB","132":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R"},G:{"16":"hB 5B","132":"F D kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"2":"OC"},I:{"16":"PC QC","132":"dB I H RC SC kB TC UC"},J:{"132":"E A"},K:{"1":"C cB","2":"A","16":"B bB jB","132":"T"},L:{"132":"H"},M:{"260":"S"},N:{"260":"A B"},O:{"132":"VC"},P:{"132":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"132":"gC"},R:{"132":"hC"},S:{"260":"iC"}},B:5,C:"Mutation events"};
