module.exports={A:{A:{"2":"J E F lB","520":"G A B"},B:{"1":"P Q R U V W X Y Z a b c S d e H","8":"C K","388":"L D M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"mB dB oB pB","132":"I f J E F G A B C K L D M N O g h i j k l m n o"},D:{"1":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"I f","132":"J E F G A B C K L D M N O g h i j k l"},E:{"2":"sB","8":"I f hB tB","520":"J E F G A B C uB vB wB iB bB","1028":"K cB xB","7172":"L","8196":"D yB zB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G 0B 1B 2B","132":"B C D 3B bB jB 4B cB"},G:{"2":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC","1028":"HC IC JC KC LC","3076":"D MC NC"},H:{"2":"OC"},I:{"1":"H","2":"PC QC","132":"dB I RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"8":"A B"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","132":"I"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:6,C:"WebM video format"};
