module.exports={A:{A:{"2":"J E F G A B lB"},B:{"1":"P Q R U V W X Y Z a b c S d e H","2":"C K L D M N O"},C:{"1":"AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","2":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z oB pB"},D:{"1":"LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","2":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB","194":"DB EB FB GB HB IB JB eB KB fB"},E:{"1":"A B C K L D iB bB cB xB yB zB","2":"I f J E F G sB hB tB uB vB wB"},F:{"1":"DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","2":"G B C D M N O g h i j k l m n o p q r s t u v w x y z 0B 1B 2B 3B bB jB 4B cB","194":"0 1 2 3 4 5 6 7 8 9 AB BB CB"},G:{"1":"D CC DC EC FC GC HC IC JC KC LC MC NC","2":"F hB 5B kB 6B 7B 8B 9B AC BC"},H:{"2":"OC"},I:{"1":"H","2":"dB I PC QC RC SC kB TC UC"},J:{"2":"E A"},K:{"1":"T","2":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"VC"},P:{"1":"ZC aC iB bC cC dC eC fC","2":"I","194":"WC XC YC"},Q:{"2":"gC"},R:{"194":"hC"},S:{"2":"iC"}},B:7,C:"#rrggbbaa hex color notation"};
