module.exports={A:{A:{"2":"lB","8":"J E F","129":"G A B"},B:{"1":"N O P Q R U V W X Y Z a b c S d e H","129":"C K L D M"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","8":"mB dB oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","8":"I f J"},E:{"1":"G A B C K L D wB iB bB cB xB yB zB","8":"I f sB hB","129":"J E F tB uB vB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R 4B cB","2":"B 3B bB jB","8":"G 0B 1B 2B"},G:{"1":"D AC BC CC DC EC FC GC HC IC JC KC LC MC NC","8":"hB 5B kB","129":"F 6B 7B 8B 9B"},H:{"1":"OC"},I:{"1":"H TC UC","2":"PC QC RC","129":"dB I SC kB"},J:{"1":"A","129":"E"},K:{"1":"C T cB","8":"A B bB jB"},L:{"1":"H"},M:{"1":"S"},N:{"129":"A B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:1,C:"Inline SVG in HTML5"};
