module.exports={A:{A:{"388":"J E F G A B lB"},B:{"1":"b c S d e H","260":"P Q R U V W X Y Z a","388":"C K L D M N O"},C:{"1":"R nB U V W X Y Z a b c S d e H gB","260":"fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q","388":"0 1 2 3 4 5 6 7 8 9 mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB oB pB"},D:{"1":"b c S d e H gB qB rB","260":"QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a","388":"0 1 2 3 4 5 6 7 8 9 I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB"},E:{"1":"zB","260":"L D xB yB","388":"I f J E F G A B C K sB hB tB uB vB wB iB bB cB"},F:{"260":"GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","388":"0 1 2 3 4 5 6 7 8 9 G B C D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB 0B 1B 2B 3B bB jB 4B cB"},G:{"260":"D LC MC NC","388":"F hB 5B kB 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC"},H:{"388":"OC"},I:{"1":"H","388":"dB I PC QC RC SC kB TC UC"},J:{"388":"E A"},K:{"1":"T","388":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"388":"A B"},O:{"388":"VC"},P:{"1":"fC","388":"I WC XC YC ZC aC iB bC cC dC eC"},Q:{"388":"gC"},R:{"388":"hC"},S:{"388":"iC"}},B:5,C:"CSS overflow property"};
