module.exports={A:{A:{"1":"B","16":"lB","132":"J E F G A"},B:{"1":"C K L D M N O P Q R U V W X Y Z a b c S d e H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","132":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","132":"I f J E F G A B C K L D M N O g h i j k"},E:{"1":"A B C K L D iB bB cB xB yB zB","132":"I f J E F G sB hB tB uB vB wB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D M N O g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","16":"G B C 0B 1B 2B 3B bB jB 4B","132":"cB"},G:{"1":"D CC DC EC FC GC HC IC JC KC LC MC NC","132":"F hB 5B kB 6B 7B 8B 9B AC BC"},H:{"132":"OC"},I:{"1":"H TC UC","132":"dB I PC QC RC SC kB"},J:{"132":"E A"},K:{"1":"T","16":"A B C bB jB","132":"cB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","132":"A"},O:{"1":"VC"},P:{"1":"WC XC YC ZC aC iB bC cC dC eC fC","132":"I"},Q:{"1":"gC"},R:{"1":"hC"},S:{"4":"iC"}},B:6,C:"localeCompare()"};
