module.exports={A:{A:{"2":"lB","8":"J E F G A","164":"B"},B:{"1":"P Q R U V W X Y Z a b c S d e H","513":"C K L D M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 v w x y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R nB U V W X Y Z a b c S d e H gB","8":"mB dB I f J E F G A B C K L D M N O g h i j k l m n o p q r s oB pB","66":"t u"},D:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB eB KB fB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R U V W X Y Z a b c S d e H gB qB rB","8":"I f J E F G A B C K L D M N O g h i j k l m n o p q r s t u v w x"},E:{"1":"B C K L D bB cB xB yB zB","8":"I f J E sB hB tB uB","289":"F G A vB wB iB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB T NB OB PB QB RB SB TB UB VB WB XB YB ZB aB P Q R","8":"G B C D M N O g h i j k 0B 1B 2B 3B bB jB 4B cB"},G:{"1":"D EC FC GC HC IC JC KC LC MC NC","8":"hB 5B kB 6B 7B 8B","289":"F 9B AC BC CC DC"},H:{"2":"OC"},I:{"1":"H","8":"dB I PC QC RC SC kB TC UC"},J:{"8":"E A"},K:{"1":"T","8":"A B C bB jB cB"},L:{"1":"H"},M:{"1":"S"},N:{"8":"A","164":"B"},O:{"1":"VC"},P:{"1":"I WC XC YC ZC aC iB bC cC dC eC fC"},Q:{"1":"gC"},R:{"1":"hC"},S:{"1":"iC"}},B:2,C:"Web Cryptography"};
